@@ -1,16 +1,6 @@
 #include <RcppArmadillo.h>
 using namespace Rcpp;
 using namespace arma;
-
-// This is a simple example of exporting a C++ function to R. You can
-// source this function into an R session using the Rcpp::sourceCpp
-// function (or via the Source button on the editor toolbar). Learn
-// more about Rcpp at:
-//
-//   http://www.rcpp.org/
-//   http://adv-r.had.co.nz/Rcpp.html
-//   http://gallery.rcpp.org/
-//
 // [[Rcpp::depends(RcppArmadillo)]]
 // [[Rcpp::export]]
 double Schott2001Stat(List x) {
@@ -25,8 +15,8 @@ double Schott2001Stat(List x) {
 
  for(int i = 0; i < len; ++i){
     arma::mat mats = x[i];
-    int nsi = mats.n_rows;
-    int ps = mats.n_cols;
+    double nsi = mats.n_rows;
+    double ps = mats.n_cols;
     arma::mat covar = cov(mats);
     samplecov[i] = covar;
     p = ps;
