@@ -1,16 +1,6 @@
 #include <RcppArmadillo.h>
 using namespace Rcpp;
 using namespace arma;
-
-// This is a simple example of exporting a C++ function to R. You can
-// source this function into an R session using the Rcpp::sourceCpp
-// function (or via the Source button on the editor toolbar). Learn
-// more about Rcpp at:
-//
-//   http://www.rcpp.org/
-//   http://adv-r.had.co.nz/Rcpp.html
-//   http://gallery.rcpp.org/
-//
 // [[Rcpp::depends(RcppArmadillo)]]
 // [[Rcpp::export]]
 double Schott2007Stat(List x) {
@@ -27,14 +17,19 @@ double Schott2007Stat(List x) {
  for(int i = 0; i < len; ++i){
     arma::mat mats = x[i];
     double ns = mats.n_rows;
-    int ps = mats.n_cols;
+    double ps = mats.n_cols;
 
     arma::mat covar = cov(mats);
     samplecov[i] = covar;
 
-    a2i[i] = pow(ns - 1.0, 2.0) *
-      pow(ps * (ns - 2.0) * (ns + 1.0), -1.0)*
-      (trace(covar * covar) - pow(ns - 1.0, -1.0) * pow(trace(covar), 2.0));
+    
+    double cov2trace = trace(covar * covar);
+    double covtrace = trace(covar);
+    
+    
+    a2i[i] = pow(ns - 1.0, 2.0) /
+      ps * (ns - 2.0) * (ns + 1.0) *
+        (cov2trace - (1.0 / (ns - 1.0))) * pow(covtrace, 2.0);
 
     Apool += covar * (ns - 1.0);
     ntot += ns - 1.0;
@@ -42,10 +37,11 @@ double Schott2007Stat(List x) {
   }
 
  arma::mat pooledCov = Apool * pow(ntot, -1);
-
+ double pooledcov2trace = trace(pooledCov * pooledCov);
+ double pooledcovtrace = trace(pooledCov);
  double a2 = pow(ntot, 2.0) *
    pow(p * (ntot - 1.0) * (ntot + 2.0), -1.0) *
-   (trace(pooledCov * pooledCov) - pow(ntot, -1.0) * pow(trace(pooledCov), 2.0));
+   (pooledcov2trace - pow(ntot, -1.0) * pow(pooledcovtrace, 2.0));
 
   double theta = 2.0 * a2 * ninv;
 
@@ -56,7 +52,8 @@ double Schott2007Stat(List x) {
     for(int j = i + 1; j < len; ++j){
       double aj = a2i[j];
       arma::mat sampcovj = samplecov[j];
-    stat += pow(pow(theta, -1.0) *  (ai + aj - 2.0 * pow(p, -1.0) * trace(sampcovi * sampcovj)), 2.0);
+      double samplecovijtrace = trace(sampcovi * sampcovj);
+    stat += pow(pow(theta, -1.0) *  (ai + aj - 2.0 * pow(p, -1.0) * samplecovijtrace), 2.0);
     }
   }
 
@@ -64,15 +61,6 @@ double Schott2007Stat(List x) {
 }
 
 
-// This is a simple example of exporting a C++ function to R. You can
-// source this function into an R session using the Rcpp::sourceCpp
-// function (or via the Source button on the editor toolbar). Learn
-// more about Rcpp at:
-//
-//   http://www.rcpp.org/
-//   http://adv-r.had.co.nz/Rcpp.html
-//   http://gallery.rcpp.org/
-//
 // [[Rcpp::depends(RcppArmadillo)]]
 // [[Rcpp::export]]
 double Schott2007pooledStat(List x) {
@@ -89,14 +77,18 @@ double Schott2007pooledStat(List x) {
   for(int i = 0; i < len; ++i){
     arma::mat mats = x[i];
     double ns = mats.n_rows;
-    int ps = mats.n_cols;
+    double ps = mats.n_cols;
 
     arma::mat covar = cov(mats);
     samplecov[i] = covar;
 
-    a2i[i] = pow(ns - 1.0, 2.0) *
-      pow(ps * (ns - 2.0) * (ns + 1.0), -1.0)*
-      (trace(covar * covar) - pow(ns - 1.0, -1.0) * pow(trace(covar), 2.0));
+    double cov2trace = trace(covar * covar);
+    double covtrace = trace(covar);
+    
+    
+    a2i[i] = pow(ns - 1.0, 2.0) /
+      ps * (ns - 2.0) * (ns + 1.0) *
+        (cov2trace - (1.0 / (ns - 1.0))) * pow(covtrace, 2.0);
 
     Apool += covar * (ns - 1.0);
     ntot += ns - 1.0;
